@@ -1,15 +1,17 @@
-from learning_loop_node.loop import LoopHttp
-from learning_loop_node.context import Context
+#
 from pydantic.main import BaseModel
 from typing import List
-from learning_loop_node.trainer.training_data import TrainingData
 import asyncio
-from learning_loop_node.node_helper import download_images_data, create_resource_paths
-from learning_loop_node import node_helper
 from icecream import ic
 import os
 from glob import glob
-from learning_loop_node.trainer.basic_data import BasicData
+from ..context import Context
+from .. import node_helper
+from ..loop import loop
+from ..node_helper import download_images_data, create_resource_paths
+from ..trainer.basic_data import BasicData
+from ..trainer.training_data import TrainingData
+import logging
 
 
 class DataDownloader(BaseModel):
@@ -22,8 +24,8 @@ class DataDownloader(BaseModel):
         return training_data
 
     async def download_basic_data(self) -> BasicData:
-        async with LoopHttp().get(f'api/{self.context.organization}/projects/{self.context.project}/data?{self.data_query_params}') as response:
-            assert response.status == 200
+        async with loop.get(f'api/{self.context.organization}/projects/{self.context.project}/data?{self.data_query_params}') as response:
+            assert response.status == 200, response
             basic_data = BasicData.parse_obj(await response.json())
             return basic_data
 
@@ -35,7 +37,7 @@ class DataDownloader(BaseModel):
         await self.download_images(loop, basic_data.image_ids, image_folder)
 
         image_data = await image_data_task
-        ic(f'Done downloading image_data for {len(image_data)} images.')
+        logging.info(f'Done downloading image_data for {len(image_data)} images.')
         return TrainingData(image_data=image_data, box_categories=basic_data.box_categories)
 
     async def download_image_data(self, ids: List[str]) -> List[dict]:
